@@ -9,7 +9,6 @@
 #' @param repel \strong{\code{\link[base]{logical}}} | Whether to repel the labels if label is set to TRUE.
 #' @param label.color \strong{\code{\link[base]{character}}} | HEX code for the color of the text in the labels if label is set to TRUE.
 #' @return  A ggplot2 object containing a DimPlot.
-#'
 #' @export
 #'
 #' @example man/examples/examples_do_DimPlot.R
@@ -52,7 +51,13 @@ do_DimPlot <- function(sample,
                        marginal.type = "density",
                        marginal.size = 5,
                        marginal.group = TRUE,
-                       plot.axes = FALSE){
+                       plot.axes = FALSE,
+                       plot_density_contour = FALSE,
+                       contour.position = "bottom",
+                       contour.color = "grey90",
+                       contour.lineend = "butt",
+                       contour.linejoin = "round",
+                       contour_expand_axes = 0.25){
   check_suggests(function_name = "do_DimPlot")
   # Check if the sample provided is a Seurat object.
   check_Seurat(sample = sample)
@@ -69,7 +74,8 @@ do_DimPlot <- function(sample,
                        "plot_marginal_distributions" = plot_marginal_distributions,
                        "marginal.group" = marginal.group,
                        "plot_cell_borders" = plot_cell_borders,
-                       "plot.axes" = plot.axes)
+                       "plot.axes" = plot.axes,
+                       "plot_density_contour" = plot_density_contour)
   check_type(parameters = logical_list, required_type = "logical", test_function = is.logical)
   # Check numeric parameters.
   numeric_list <- list("pt.size" = pt.size,
@@ -81,7 +87,8 @@ do_DimPlot <- function(sample,
                        "ncol" = ncol,
                        "raster.dpi" = raster.dpi,
                        "marginal.size" = marginal.size,
-                       "border.size" = border.size)
+                       "border.size" = border.size,
+                       "contour_expand_axes" = contour_expand_axes)
   check_type(parameters = numeric_list, required_type = "numeric", test_function = is.numeric)
   # Check character parameters.
   character_list <- list("legend.position" = legend.position,
@@ -97,7 +104,11 @@ do_DimPlot <- function(sample,
                          "legend.title.position" = legend.title.position,
                          "font.type" = font.type,
                          "marginal.type" = marginal.type,
-                         "border.color" = border.color)
+                         "border.color" = border.color,
+                         "contour.position" = contour.position,
+                         "contour.color" = contour.color,
+                         "contour.lineend" = contour.lineend,
+                         "contour.linejoin" = contour.linejoin)
   check_type(parameters = character_list, required_type = "character", test_function = is.character)
 
   # Checks to ensure proper function.
@@ -106,9 +117,6 @@ do_DimPlot <- function(sample,
   split_by_and_highlighting_cells <- (!(is.null(cells.highlight)) | !(is.null(idents.highlight))) & !(is.null(split.by))
   order_and_shuffle_used <- !(is.null(order)) & isTRUE(shuffle)
 
-  #assertthat::assert_that(!group_by_and_split_by_used,
-  #                        msg = "Either group.by or split.by has to be NULL.")
-
   assertthat::assert_that(!group_by_and_highlighting_cells,
                           msg = "Either group.by or cells.highlight has to be NULL.")
 
@@ -124,10 +132,20 @@ do_DimPlot <- function(sample,
   check_colors(na.value, parameter_name = "na.value")
   ## Check the color assigned to border.color.
   check_colors(border.color, parameter_name = "border.color")
+  ## Check the color assigned to contour.color.
+  check_colors(contour.color, parameter_name = "contour.color")
+
   ## If the user provides more than one color to na.value, stop the function.
   assertthat::assert_that(length(na.value) == 1,
                           msg = "Please provide only one color to na.value.")
 
+  ## Check that the contour_expand_axes is between 0 and 1.
+  assertthat::assert_that(contour_expand_axes <= 1,
+                          msg = "Please provide a value to contour_expand_axes lower or equal than 1.")
+
+  assertthat::assert_that(contour_expand_axes >= 0,
+                          msg = "Please provide a value to contour_expand_axes higher or equal than 1.")
+
   # If the user provides raster = TRUE but the pt.size is less than 1, warn it.
   if (isTRUE(raster) & pt.size < 1){
     warning("Setting raster = TRUE and pt.size < 1 will result in the cells being ploted as a cross. This behaviour can not be modified, but setting pt.size to 1 or higher solves it. For DimPlots, optimized values would be pt.size = 3 and raster.dpi = 2048.", call. = FALSE)
@@ -136,6 +154,9 @@ do_DimPlot <- function(sample,
   check_parameters(parameter = font.type, parameter_name = "font.type")
   check_parameters(parameter = legend.position, parameter_name = "legend.position")
   check_parameters(parameter = marginal.type, parameter_name = "marginal.type")
+  check_parameters(parameter = contour.lineend, parameter_name = "contour.lineend")
+  check_parameters(parameter = contour.linejoin, parameter_name = "contour.linejoin")
+  check_parameters(parameter = contour.position, parameter_name = "contour.position")
 
   # If the user has not provided colors.
   if (is.null(colors.use)){
@@ -284,22 +305,41 @@ do_DimPlot <- function(sample,
   highlighting_cells <- !(is.null(cells.highlight)) | !(is.null(idents.highlight))
   # When running under default parameters or using group.by
   if (not_highlighting_and_not_split_by){
-    p <- Seurat::DimPlot(sample,
-                         reduction = reduction,
-                         label = label,
-                         dims = dims,
-                         repel = ifelse(is.null(label) == TRUE, NULL, TRUE),
-                         label.box = ifelse(is.null(label) == TRUE, NULL, TRUE),
-                         label.color = ifelse(is.null(label) == TRUE, NULL, label.color),
-                         na.value = na.value,
-                         shuffle = shuffle,
-                         order = order,
-                         pt.size = pt.size,
-                         group.by = group.by,
-                         cols = colors.use,
-                         raster = raster,
-                         raster.dpi = c(raster.dpi, raster.dpi),
-                         ncol = ncol) &
+    if (utils::packageVersion("Seurat") >= "4.1.0"){
+      p <- Seurat::DimPlot(sample,
+                           reduction = reduction,
+                           label = label,
+                           dims = dims,
+                           repel = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                           label.box = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                           label.color = ifelse(is.null(label) == TRUE, NULL, label.color),
+                           na.value = na.value,
+                           shuffle = shuffle,
+                           order = order,
+                           pt.size = pt.size,
+                           group.by = group.by,
+                           cols = colors.use,
+                           raster = raster,
+                           raster.dpi = c(raster.dpi, raster.dpi),
+                           ncol = ncol)
+    } else {
+      p <- Seurat::DimPlot(sample,
+                           reduction = reduction,
+                           label = label,
+                           dims = dims,
+                           repel = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                           label.box = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                           label.color = ifelse(is.null(label) == TRUE, NULL, label.color),
+                           na.value = na.value,
+                           shuffle = shuffle,
+                           order = order,
+                           pt.size = pt.size,
+                           group.by = group.by,
+                           cols = colors.use,
+                           raster = raster,
+                           ncol = ncol)
+    }
+    p <- p &
       ggplot2::guides(color = ggplot2::guide_legend(ncol = legend.ncol,
                                                     nrow = legend.nrow,
                                                     byrow = legend.byrow,
@@ -320,6 +360,31 @@ do_DimPlot <- function(sample,
     if (isTRUE(plot_cell_borders)){
       p$layers <- append(base_layer, p$layers)
     }
+
+    if (isTRUE(plot_density_contour)){
+      data <- ggplot2::ggplot_build(p)
+
+      density_layer <- ggplot2::stat_density_2d(data = data$data[[1]],
+                                                mapping = ggplot2::aes(x = .data$x,
+                                                                       y = .data$y),
+                                                color = contour.color,
+                                                lineend = contour.lineend,
+                                                linejoin = contour.linejoin)
+      if (contour.position == "bottom"){
+        p$layers <- append(density_layer, p$layers)
+      } else if (contour.position == "top"){
+        p$layers <- append(p$layers, density_layer)
+      }
+
+      min_x <- min(data$data[[1]]$x) * (1 + contour_expand_axes)
+      max_x <- max(data$data[[1]]$x) * (1 + contour_expand_axes)
+      min_y <- min(data$data[[1]]$y) * (1 + contour_expand_axes)
+      max_y <- max(data$data[[1]]$y) * (1 + contour_expand_axes)
+      # Expand axes limits to allocate the new contours.
+      p <- p +
+           ggplot2::xlim(c(min_x, max_x)) +
+           ggplot2::ylim(c(min_y, max_y))
+    }
   } else if (group_by_and_split_by_used){
     list.plots <- list()
     unique_values <- if(is.factor(sample@meta.data[, split.by])){levels(sample@meta.data[, split.by])} else {sort(unique(sample@meta.data[, split.by]))}
@@ -330,28 +395,61 @@ do_DimPlot <- function(sample,
       labels <- colnames(sample@reductions[[reduction]][[]])[dims]
       df <- data.frame(x = Seurat::Embeddings(sample, reduction = reduction)[, labels[1]],
                        y = Seurat::Embeddings(sample, reduction = reduction)[, labels[2]])
-      na_layer <- ggplot2::geom_point(data = df, mapping = ggplot2::aes(x = .data$x,
-                                                                        y = .data$y),
-                                      colour = na.value,
-                                      size = pt.size,
-                                      show.legend = FALSE)
 
-      p.loop <- Seurat::DimPlot(sample[, sample@meta.data[, split.by] == value],
-                           reduction = reduction,
-                           group.by = group.by,
-                           label = label,
-                           dims = dims,
-                           repel = ifelse(is.null(label) == TRUE, NULL, TRUE),
-                           label.box = ifelse(is.null(label) == TRUE, NULL, TRUE),
-                           label.color = ifelse(is.null(label) == TRUE, NULL, label.color),
-                           na.value = na.value,
-                           shuffle = shuffle,
-                           order = order,
-                           pt.size = pt.size,
-                           cols = colors.use,
-                           raster = raster,
-                           raster.dpi = c(raster.dpi, raster.dpi),
-                           ncol = ncol) +
+
+      if (isFALSE(raster)){
+        na_layer <- ggplot2::geom_point(data = df, mapping = ggplot2::aes(x = .data$x,
+                                                                          y = .data$y),
+                                        colour = na.value,
+                                        size = pt.size,
+                                        show.legend = FALSE)
+      } else if (isTRUE(raster)){
+        na_layer <- scattermore::geom_scattermore(data = df,
+                                                  mapping = ggplot2::aes(x = .data$x,
+                                                                         y = .data$y),
+                                                  color = na.value,
+                                                  size = pt.size,
+                                                  stroke = pt.size / 2,
+                                                  show.legend = FALSE,
+                                                  pointsize = pt.size,
+                                                  pixels = c(raster.dpi, raster.dpi))
+      }
+
+      sample.use <- sample[, sample@meta.data[, split.by] == value]
+
+      if (utils::packageVersion("Seurat") >= "4.1.0"){
+        p.loop <- Seurat::DimPlot(sample.use,
+                                  reduction = reduction,
+                                  group.by = group.by,
+                                  label = label,
+                                  dims = dims,
+                                  repel = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                                  label.box = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                                  label.color = ifelse(is.null(label) == TRUE, NULL, label.color),
+                                  na.value = na.value,
+                                  shuffle = shuffle,
+                                  order = order,
+                                  pt.size = pt.size,
+                                  cols = colors.use,
+                                  raster = raster,
+                                  raster.dpi = c(raster.dpi, raster.dpi))
+      } else {
+        p.loop <- Seurat::DimPlot(sample.use,
+                                  reduction = reduction,
+                                  group.by = group.by,
+                                  label = label,
+                                  dims = dims,
+                                  repel = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                                  label.box = ifelse(is.null(label) == TRUE, NULL, TRUE),
+                                  label.color = ifelse(is.null(label) == TRUE, NULL, label.color),
+                                  na.value = na.value,
+                                  shuffle = shuffle,
+                                  order = order,
+                                  pt.size = pt.size,
+                                  cols = colors.use,
+                                  raster = raster)
+      }
+      p.loop <- p.loop +
                 ggplot2::ggtitle(value) +
                 ggplot2::guides(color = ggplot2::guide_legend(title = legend.title,
                                                               ncol = legend.ncol,
@@ -362,6 +460,31 @@ do_DimPlot <- function(sample,
       if (isTRUE(label)){
         p.loop$layers[[length(p.loop$layers)]]$aes_params$fontface <- "bold"
       }
+
+      # Add another layer of black dots to make the colored ones stand up.
+      if (isTRUE(plot_cell_borders)){
+        df.subset <- data.frame(x = Seurat::Embeddings(sample.use, reduction = reduction)[, labels[1]],
+                                y = Seurat::Embeddings(sample.use, reduction = reduction)[, labels[2]])
+
+        if (isFALSE(raster)){
+          base_layer.subset <- ggplot2::geom_point(data = df.subset, mapping = ggplot2::aes(x = .data$x,
+                                                                              y = .data$y),
+                                                   colour = border.color,
+                                                   size = pt.size * border.size,
+                                                   show.legend = FALSE)
+        } else if (isTRUE(raster)){
+          base_layer.subset <- scattermore::geom_scattermore(data = df.subset,
+                                                             mapping = ggplot2::aes(x = .data$x,
+                                                                                    y = .data$y),
+                                                             color = border.color,
+                                                             size = pt.size * border.size,
+                                                             stroke = pt.size / 2,
+                                                             show.legend = FALSE,
+                                                             pointsize = pt.size * border.size,
+                                                             pixels = c(raster.dpi, raster.dpi))
+        }
+        p.loop$layers <- append(base_layer.subset, p.loop$layers)
+      }
       # Add NA layer.
       p.loop$layers <- append(na_layer, p.loop$layers)
 
@@ -369,6 +492,32 @@ do_DimPlot <- function(sample,
       if (isTRUE(plot_cell_borders)){
         p.loop$layers <- append(base_layer, p.loop$layers)
       }
+
+      if (isTRUE(plot_density_contour)){
+        data <- ggplot2::ggplot_build(p.loop)
+
+        density_layer <- ggplot2::stat_density_2d(data = data$data[[1]],
+                                                  mapping = ggplot2::aes(x = .data$x,
+                                                                         y = .data$y),
+                                                  color = contour.color,
+                                                  lineend = contour.lineend,
+                                                  linejoin = contour.linejoin)
+        if (contour.position == "bottom"){
+          p.loop$layers <- append(density_layer, p.loop$layers)
+        } else if (contour.position == "top"){
+          p.loop$layers <- append(p.loop$layers, density_layer)
+        }
+
+        min_x <- min(data$data[[1]]$x) * (1 + contour_expand_axes)
+        max_x <- max(data$data[[1]]$x) * (1 + contour_expand_axes)
+        min_y <- min(data$data[[1]]$y) * (1 + contour_expand_axes)
+        max_y <- max(data$data[[1]]$y) * (1 + contour_expand_axes)
+        # Expand axes limits to allocate the new contours.
+        p.loop <- p.loop +
+          ggplot2::xlim(c(min_x, max_x)) +
+          ggplot2::ylim(c(min_y, max_y))
+      }
+
       list.plots[[value]] <- p.loop
     }
     p <- patchwork::wrap_plots(list.plots, ncol = ncol, guides = "collect") +
@@ -396,15 +545,28 @@ do_DimPlot <- function(sample,
     for (iteration in plot_order){
       # Retrieve the cells that do belong to the iteration's split.by value.
       cells.highlight <- rownames(data.use)[which(data.use == iteration)]
-      p <- Seurat::DimPlot(sample,
-                           reduction = reduction,
-                           dims = dims,
-                           cells.highlight = cells.highlight,
-                           sizes.highlight = sizes.highlight,
-                           pt.size = pt.size,
-                           raster = raster,
-                           raster.dpi = c(raster.dpi, raster.dpi),
-                           ncol = ncol) &
+
+      if (utils::packageVersion("Seurat") >= "4.1.0"){
+        p <- Seurat::DimPlot(sample,
+                             reduction = reduction,
+                             dims = dims,
+                             cells.highlight = cells.highlight,
+                             sizes.highlight = sizes.highlight,
+                             pt.size = pt.size,
+                             raster = raster,
+                             raster.dpi = c(raster.dpi, raster.dpi),
+                             ncol = ncol)
+      } else {
+        p <- Seurat::DimPlot(sample,
+                             reduction = reduction,
+                             dims = dims,
+                             cells.highlight = cells.highlight,
+                             sizes.highlight = sizes.highlight,
+                             pt.size = pt.size,
+                             raster = raster,
+                             ncol = ncol)
+      }
+      p <- p &
         ggplot2::labs(title = iteration)
       p <- add_scale(p = p,
                      function_use = ggplot2::scale_color_manual(labels = c("Not selected", iteration),
@@ -421,6 +583,32 @@ do_DimPlot <- function(sample,
       if (isTRUE(plot_cell_borders)){
         p$layers <- append(base_layer, p$layers)
       }
+
+      if (isTRUE(plot_density_contour)){
+        data <- ggplot2::ggplot_build(p)
+
+        density_layer <- ggplot2::stat_density_2d(data = data$data[[1]],
+                                                  mapping = ggplot2::aes(x = .data$x,
+                                                                         y = .data$y),
+                                                  color = contour.color,
+                                                  lineend = contour.lineend,
+                                                  linejoin = contour.linejoin)
+        if (contour.position == "bottom"){
+          p$layers <- append(density_layer, p$layers)
+        } else if (contour.position == "top"){
+          p$layers <- append(p$layers, density_layer)
+        }
+
+        min_x <- min(data$data[[1]]$x) * (1 + contour_expand_axes)
+        max_x <- max(data$data[[1]]$x) * (1 + contour_expand_axes)
+        min_y <- min(data$data[[1]]$y) * (1 + contour_expand_axes)
+        max_y <- max(data$data[[1]]$y) * (1 + contour_expand_axes)
+        # Expand axes limits to allocate the new contours.
+        p <- p +
+          ggplot2::xlim(c(min_x, max_x)) +
+          ggplot2::ylim(c(min_y, max_y))
+      }
+
       list.plots[[iteration]] <- p
     }
     # Assemble individual plots as a patch.
@@ -447,15 +635,28 @@ do_DimPlot <- function(sample,
       cells.2 <- names(Seurat::Idents(sample)[Seurat::Idents(sample) %in% idents.highlight])
       cells.use <- unique(c(cells.1, cells.2))
     }
-    p <- Seurat::DimPlot(sample,
-                         reduction = reduction,
-                         cells.highlight = cells.use,
-                         sizes.highlight = sizes.highlight,
-                         dims = dims,
-                         pt.size = pt.size,
-                         raster = raster,
-                         raster.dpi = c(raster.dpi, raster.dpi),
-                         ncol = ncol)
+
+    if (utils::packageVersion("Seurat") >= "4.1.0"){
+      p <- Seurat::DimPlot(sample,
+                           reduction = reduction,
+                           cells.highlight = cells.use,
+                           sizes.highlight = sizes.highlight,
+                           dims = dims,
+                           pt.size = pt.size,
+                           raster = raster,
+                           raster.dpi = c(raster.dpi, raster.dpi),
+                           ncol = ncol)
+    } else {
+      p <- Seurat::DimPlot(sample,
+                           reduction = reduction,
+                           cells.highlight = cells.use,
+                           sizes.highlight = sizes.highlight,
+                           dims = dims,
+                           pt.size = pt.size,
+                           raster = raster,
+                           ncol = ncol)
+    }
+
     p <- add_scale(p = p,
                    function_use = ggplot2::scale_color_manual(labels = c("Not selected", "Selected"),
                                                               values = c(na.value, colors.use),
@@ -473,6 +674,31 @@ do_DimPlot <- function(sample,
       p$layers <- append(base_layer, p$layers)
     }
 
+    if (isTRUE(plot_density_contour)){
+      data <- ggplot2::ggplot_build(p)
+
+      density_layer <- ggplot2::stat_density_2d(data = data$data[[1]],
+                                                mapping = ggplot2::aes(x = .data$x,
+                                                                       y = .data$y),
+                                                color = contour.color,
+                                                lineend = contour.lineend,
+                                                linejoin = contour.linejoin)
+      if (contour.position == "bottom"){
+        p$layers <- append(density_layer, p$layers)
+      } else if (contour.position == "top"){
+        p$layers <- append(p$layers, density_layer)
+      }
+
+      min_x <- min(data$data[[1]]$x) * (1 + contour_expand_axes)
+      max_x <- max(data$data[[1]]$x) * (1 + contour_expand_axes)
+      min_y <- min(data$data[[1]]$y) * (1 + contour_expand_axes)
+      max_y <- max(data$data[[1]]$y) * (1 + contour_expand_axes)
+      # Expand axes limits to allocate the new contours.
+      p <- p +
+        ggplot2::xlim(c(min_x, max_x)) +
+        ggplot2::ylim(c(min_y, max_y))
+    }
+
   }
   # Titles in split.by are centered by default.
   hjust_use <- if(split_by_used){0.5} else {0}
