@@ -3,6 +3,8 @@
   value <- SCpubr:::check_suggests(function_name = "do_BoxPlot", passive = TRUE)
 
   if (isTRUE(value)){
+    # Consult the full documentation in https://enblacar.github.io/SCpubr-book/
+
     # Define your Seurat object.
     sample <- readRDS(system.file("extdata/seurat_dataset_example.rds", package = "SCpubr"))
 
@@ -11,21 +13,6 @@
                             feature = "nCount_RNA")
     p
 
-    # Generate a custom group.
-    sample$custom_group = ifelse(colnames(sample) %in% sample(colnames(sample), 50), "A", "B")
-
-    # Use custom grouping.
-    p <- SCpubr::do_BoxPlot(sample = sample,
-                            feature = "nCount_RNA",
-                            group.by = "custom_group")
-    p
-
-    # Flip the box plot.
-    p <- SCpubr::do_BoxPlot(sample = sample,
-                            feature = "nCount_RNA",
-                            flip = TRUE)
-    p
-
     # Use silhouette style.
     p <- SCpubr::do_BoxPlot(sample = sample,
                             feature = "nCount_RNA",
@@ -39,13 +26,13 @@
     p
 
     # Apply second grouping.
+    sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("0", "1", "2", "3"), "A", "B")
     p <- SCpubr::do_BoxPlot(sample = sample,
                             feature = "nCount_RNA",
-                            split.by = "custom_group")
+                            split.by = "orig.ident")
     p
 
     # Apply statistical tests.
-    sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("0", "1", "2", "3"), "A", "B")
     p <- SCpubr::do_BoxPlot(sample = sample,
                             feature = "nCount_RNA",
                             group.by = "orig.ident",
@@ -53,14 +40,6 @@
                             comparisons = list(c("A", "B")))
     p
 
-    # Apply statistical tests and show the p-value.
-    p <- SCpubr::do_BoxPlot(sample = sample,
-                            feature = "nCount_RNA",
-                            group.by = "orig.ident",
-                            use_test = TRUE,
-                            comparisons = list(c("A", "B")),
-                            map_signif_level = FALSE)
-    p
   } else if (isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
