@@ -1,6 +1,22 @@
 if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
-  testthat::test_that("do_EnrichmentHeatmap: PASS - normal", {
 
+  testthat::test_that("do_EnrichmentHeatmap: CRAN essential", {
+    sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
+
+    genes <- list("A" = Seurat::VariableFeatures(sample)[1:5],
+                  "B" = Seurat::VariableFeatures(sample)[6:10],
+                  "C" = Seurat::VariableFeatures(sample)[11:15])
+
+
+    p <- SCpubr::do_EnrichmentHeatmap(sample = sample,
+                                      input_gene_list = genes,
+                                      nbin = 1,
+                                      ctrl = 10)
+    testthat::expect_true("HeatmapList" %in% class(p))
+  })
+
+  testthat::test_that("do_EnrichmentHeatmap: PASS - normal", {
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -31,7 +47,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
   })
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - group.by", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -48,7 +64,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
   })
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - group.by and flip", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -66,7 +82,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
   })
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - group.by and flip and column_names_rot", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -85,7 +101,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
   })
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - group.by and flip and row_names_rot", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -106,7 +122,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
 
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - multiple variables changing cell size", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -128,7 +144,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
 
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - character list of genes + group by only has 1 entity", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -145,7 +161,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
   })
 
   testthat::test_that("do_EnrichmentHeatmap: FAIL - list of genes without name", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -168,7 +184,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
   })
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - group by factor", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -186,7 +202,7 @@ if (isFALSE(dep_check[["do_EnrichmentHeatmap"]])){
   })
 
   testthat::test_that("do_EnrichmentHeatmap: PASS - row title and column title", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
