@@ -1,32 +1,68 @@
 if(isFALSE(dep_check[["do_ViolinPlot"]])){
-  testthat::test_that("do_ViolinPlot: PASS - one variable", {
+  testthat::test_that("do_ViolinPlot: CRAN essentials", {
 
+    p <- SCpubr::do_ViolinPlot(sample = sample,
+                               features = "EPC1")
+    testthat::expect_type(p, "list")
+  })
+
+  testthat::test_that("do_ViolinPlot: PASS - one variable", {
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
                                plot.grid = TRUE)
     testthat::expect_type(p, "list")
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
+                               plot.grid = FALSE)
+    testthat::expect_type(p, "list")
+  })
+
+  testthat::test_that("do_ViolinPlot: PASS - two variable", {
+    testthat::skip_on_cran()
+
+
+    p <- SCpubr::do_ViolinPlot(sample = sample,
+                               features = c("EPC1", "TOX2"),
+                               plot.grid = TRUE)
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_ViolinPlot(sample = sample,
+                               features = c("EPC1", "TOX2"),
+                               plot.grid = TRUE,
+                               share.y.lims = TRUE)
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_ViolinPlot(sample = sample,
+                               features = c("EPC1", "TOX2"),
+                               plot.grid = TRUE,
+                               xlab = c("A", "A"),
+                               ylab = c("B", "B"),
+                               y_cut = c(400, 400))
+    testthat::expect_type(p, "list")
+
+    p <- SCpubr::do_ViolinPlot(sample = sample,
+                               features = c("EPC1", "TOX2"),
                                plot.grid = FALSE)
     testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_ViolinPlot: PASS - group.by", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
                                plot.grid = TRUE,
                                group.by = "seurat_clusters")
     testthat::expect_type(p, "list")
 
     sample$seurat_clusters <- as.character(sample$seurat_clusters)
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
                                plot.grid = FALSE,
                                group.by = "seurat_clusters")
     testthat::expect_type(p, "list")
@@ -34,31 +70,31 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
   testthat::test_that("do_ViolinPlot: PASS - without boxplot", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
                                plot_boxplot = FALSE)
     testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_ViolinPlot: PASS - rotate axis", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
-                               rotate_x_axis_labels = TRUE)
+                               features = "EPC1",
+                               rotate_x_axis_labels = 45)
     testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_ViolinPlot: PASS - plot.grid", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = c("EPC1"),
+                               features = c("EPC1"),
                                plot.grid = TRUE)
     testthat::expect_type(p, "list")
   })
@@ -66,49 +102,49 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
 
-  testthat::test_that("do_ViolinPlot: PASS - one feature ycut", {
-
+  testthat::test_that("do_ViolinPlot: PASS - one features ycut", {
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = c("EPC1"),
-                               rotate_x_axis_labels = TRUE,
+                               features = c("EPC1"),
+                               rotate_x_axis_labels = 45,
                                y_cut = 2)
     testthat::expect_type(p, "list")
   })
 
 
-  testthat::test_that("do_ViolinPlot: PASS - one feature line width", {
-
+  testthat::test_that("do_ViolinPlot: PASS - one features line width", {
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = c("EPC1"),
-                               rotate_x_axis_labels = TRUE,
+                               features = c("EPC1"),
+                               rotate_x_axis_labels = 45,
                                y_cut = 2,
                                line_width = 3)
     testthat::expect_type(p, "list")
   })
 
-  testthat::test_that("do_ViolinPlot: PASS - one feature boxplot width", {
-
+  testthat::test_that("do_ViolinPlot: PASS - one features boxplot width", {
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = c("EPC1"),
-                               rotate_x_axis_labels = TRUE,
+                               features = c("EPC1"),
+                               rotate_x_axis_labels = 45,
                                y_cut = 2,
                                boxplot_width = 0.1)
     testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_ViolinPlot: PASS - change colors", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = c("EPC1"),
-                               rotate_x_axis_labels = TRUE,
+                               features = c("EPC1"),
+                               rotate_x_axis_labels = 45,
                                y_cut = 2,
                                boxplot_width = 0.1,
                                colors.use = c("0" = "#001219",
@@ -126,11 +162,11 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
   testthat::test_that("do_ViolinPlot: FAIL - split.by", {
-
+    testthat::skip_on_cran()
 
 
     testthat::expect_error(SCpubr::do_ViolinPlot(sample = sample,
-                                                 feature = c("EPC1"),
+                                                 features = c("EPC1"),
                                                  split.by = "orig.ident"))
   })
 
@@ -138,21 +174,21 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
   testthat::test_that("do_ViolinPlot: PASS - one variable, group by", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
                                group.by = "orig.ident")
     testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_ViolinPlot: PASS - one variable, xlab y lab", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
                                xlab = "y",
                                ylab = "x")
     testthat::expect_type(p, "list")
@@ -160,11 +196,11 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
   testthat::test_that("do_ViolinPlot: PASS - one variable, plot.title, subtitle and caption", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
-                               feature = "EPC1",
+                               features = "EPC1",
                                plot.title = "A",
                                plot.subtitle = "B",
                                plot.caption = "C")
@@ -173,7 +209,7 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
 
 
   testthat::test_that("do_ViolinPlot: PASS - multiple variables plot.title, subtitle and caption", {
-
+    testthat::skip_on_cran()
 
 
     p <- SCpubr::do_ViolinPlot(sample = sample,
@@ -191,11 +227,11 @@ if(isFALSE(dep_check[["do_ViolinPlot"]])){
   })
 
   testthat::test_that("do_ViolinPlot: FAIL - wrong font.type", {
-
+    testthat::skip_on_cran()
 
 
     testthat::expect_error(SCpubr::do_ViolinPlot(sample = sample,
-                                                 feature = c("EPC1"),
+                                                 features = c("EPC1"),
                                                  font.type = "wrong"))
   })
 }
